' Global variables
Dim oRSS
Dim iCnt, iMaxItems
Dim Nodes, Node
Dim sChannelName, sChannelURL, sChannelSelection
Dim sProperty

' Initialize variables
iMaxItems = 5
iCnt = 0

' Get the currently selected Channel Name and Channel URL
sChannelSelection = GetPropertyValue("News.News Channel Selection")

If CheckChannel(sChannelSelection) then
	' Open an XML DOM object and load it with the contents of the RSS page.
	Set oRSS = CreateObject("MSXML2.DOMDocument")
	oRSS.Async = False
	oRSS.Load(sChannelURL)

	' Erase all of the old news items
	ClearOldNews

	' Ensure the RSS page was loaded correctly
	If (oRSS.parseError.errorCode <> 0) Then
		SetpropertyValue "News.News Channel Name", "Error: " & oRSS.parseError.reason
	Else
			' 
			Set Nodes = oRSS.selectNodes("//item")
			For Each Node In Nodes
				If (iCnt < iMaxItems) Then
					iCnt = iCnt + 1
					sProperty = "News.News " & iCnt & " "
					With Node
					on error resume next
					SetPropertyValue sProperty & "Headline", .selectSingleNode("title").Text
					SetPropertyValue sProperty & "Date", .selectSingleNode("pubDate").Text
					SetPropertyValue sProperty & "Text", .selectSingleNode("description").Text
					on error Goto 0              
					End With
				End If
			Next
	End If
End If

' Ensure the supplied News Channel Selection is valid.
' It must be in the following format:
' Channel Name  |   Channel URL
' Example: CBC WorldNews | http://rss.cbc.ca/worldnews.xml
' Spaces before and after the "|" delimiter are optional and
' are used to improve readibility.
Function CheckChannel(sChannel)
	Dim iPosn

	' Ensure the Channel Selction string is not zero-length
	If len(sChannel) < 1 then
		SetpropertyValue "News.News Channel Name", "Error: No Channel selection."
		CheckChannel = False
	Else
		' Find the position of the delimiter within the Channel Selection string
		iPosn = instr(sChannel, "|")
		If iPosn > 1 Then
			sChannelName = trim(mid(sChannel,1,iPosn-1))
			sChannelURL = trim(mid(sChannel,iPosn+1))
			' Ensure neither the Chanbel Name nor Channel URL are zero-length
			If len(sChannelName) < 1 or len(sChannelURL) < 1 then
				SetpropertyValue "News.News Channel Name", "Error: No Channel name and/or URL."
				CheckChannel = False
			Else
				' Channel Name and Channel URL are valid
				SetpropertyValue "News.News Channel Name", sChannelName
				SetpropertyValue "News.News Channel URL", sChannelURL
				CheckChannel = True
			End If
		Else
			SetpropertyValue "News.News Channel Name", "Error: Selected Channel data lacks a valid delimiter."
			CheckChannel = False
		End If
	End If
End Function

' Erase all of the existing News items.
Sub ClearOldNews()
	For iCnt = 1 to iMaxItems
		sProperty = "News.News " & iCnt & " "
		SetPropertyValue sProperty & "Headline", ""
		SetPropertyValue sProperty & "Date", ""
		SetPropertyValue sProperty & "Text", ""
	next
	iCnt = 0
end sub
